@@ -1,14 +1,15 @@
 #!/usr/bin/env -S bash
 
-# Ensure exactly one argument is provided.
-if [ "$#" -ne 1 ]; then
+# Ensure at least one argument is provided.
+if [ "$#" -lt 1 ]; then
     # Print usage information to standard error.
     echo "Error: No application specified." >&2
-    echo "Usage: $0 {kitty|ghostty|foot|alacritty|wezterm|fuzzel|walker|pywalfox|cava|niri}" >&2
+    echo "Usage: $0 {kitty|ghostty|foot|alacritty|wezterm|fuzzel|walker|pywalfox|cava|niri|hyprland|mango} [dark|light]" >&2
     exit 1
 fi
 
 APP_NAME="$1"
+MODE="${2:-}"  # Optional second argument for dark/light mode
 
 # --- Apply theme based on the application name ---
 case "$APP_NAME" in
@@ -202,6 +203,16 @@ vicinae)
 
 pywalfox)
     echo "🎨 Updating pywalfox themes..."
+    # Set dark/light mode first if MODE is specified
+    if [ -n "$MODE" ]; then
+        if [ "$MODE" = "dark" ] || [ "$MODE" = "light" ]; then
+            echo "Setting pywalfox to $MODE mode..."
+            pywalfox "$MODE"
+        else
+            echo "Warning: Invalid mode '$MODE'. Expected 'dark' or 'light'. Skipping mode switch." >&2
+        fi
+    fi
+    # Update the theme
     pywalfox update
     ;;
 
@@ -272,7 +283,7 @@ niri)
     if [ ! -f "$CONFIG_FILE" ]; then
         echo "Config file not found, creating $CONFIG_FILE..."
         mkdir -p "$(dirname "$CONFIG_FILE")"
-        echo "$INCLUDE_LINE" >"$CONFIG_FILE"
+        echo -e "\n$INCLUDE_LINE\n" >"$CONFIG_FILE"
         echo "Created new config file with noctalia theme."
     else
         # Check if include line already exists
@@ -280,7 +291,7 @@ niri)
             echo "Theme already included, skipping modification."
         else
             # Add the include line to the end of the file
-            echo "$INCLUDE_LINE" >>"$CONFIG_FILE"
+            echo -e "\n$INCLUDE_LINE\n" >>"$CONFIG_FILE"
             echo "✅ Added noctalia theme include to config."
         fi
     fi
@@ -295,7 +306,7 @@ hyprland)
     if [ ! -f "$CONFIG_FILE" ]; then
         echo "Config file not found, creating $CONFIG_FILE..."
         mkdir -p "$(dirname "$CONFIG_FILE")"
-        echo "$INCLUDE_LINE" >"$CONFIG_FILE"
+        echo -e "\n$INCLUDE_LINE\n" >"$CONFIG_FILE"
         echo "Created new config file with noctalia theme."
     else
         # Check if include line already exists
@@ -303,7 +314,7 @@ hyprland)
             echo "Theme already included, skipping modification."
         else
             # Add the include line to the end of the file
-            echo "$INCLUDE_LINE" >>"$CONFIG_FILE"
+            echo -e "\n$INCLUDE_LINE\n" >>"$CONFIG_FILE"
             echo "✅ Added noctalia theme include to config."
         fi
     fi
@@ -363,10 +374,10 @@ mango)
         if [ -f "$MAIN_CONFIG" ]; then
             echo "" >>"$MAIN_CONFIG"
             echo "# This sources the noctalia theme" >>"$MAIN_CONFIG"
-            echo "$SOURCE_LINE" >>"$MAIN_CONFIG"
+            echo -e "\n$SOURCE_LINE\n" >>"$MAIN_CONFIG"
         else
             echo "# This sources the noctalia theme" >"$MAIN_CONFIG"
-            echo "$SOURCE_LINE" >>"$MAIN_CONFIG"
+            echo -e "\n$SOURCE_LINE\n" >>"$MAIN_CONFIG"
         fi
 
         echo "✅ Added noctalia theme to config."
